use super::*;

#[test]
fn test_dnssec_serialization() {
    let rand = enc::Random::new();
    let (_, exchange_key) =
        match enc::asym::KeyExchangeKind::X25519DiffieHellman.new_keypair(&rand)
        {
            Ok(pair) => pair,
            Err(_) => {
                assert!(false, "Can't generate random keypair");
                return;
            }
        };
    use crate::{connection::handshake::HandshakeID, enc};

    let record = Record {
        public_keys: [(
            enc::asym::KeyID(42),
            enc::asym::PubKey::Exchange(exchange_key),
        )]
        .to_vec(),
        addresses: [record::Address {
            ip: ::std::net::IpAddr::V4(::std::net::Ipv4Addr::new(127, 0, 0, 1)),
            port: Some(::core::num::NonZeroU16::new(31337).unwrap()),
            priority: record::AddressPriority::P1,
            weight: record::AddressWeight::W1,
            handshake_ids: [HandshakeID::DirectorySynchronized].to_vec(),
            public_key_idx: [record::PubKeyIdx(0)].to_vec(),
        }]
        .to_vec(),
        key_exchanges: [enc::asym::KeyExchangeKind::X25519DiffieHellman]
            .to_vec(),
        hkdfs: [enc::hkdf::HkdfKind::Sha3].to_vec(),
        ciphers: [enc::sym::CipherKind::XChaCha20Poly1305].to_vec(),
    };
    let encoded = match record.encode() {
        Ok(encoded) => encoded,
        Err(e) => {
            assert!(false, "{}", e.to_string());
            return;
        }
    };
    let full_record = "v=Fenrir1 ".to_string() + &encoded;
    let record = match Dnssec::parse_txt_record(&full_record) {
        Ok(record) => record,
        Err(e) => {
            assert!(false, "{}", e.to_string());
            return;
        }
    };
    let _re_encoded = match record.encode() {
        Ok(re_encoded) => re_encoded,
        Err(e) => {
            assert!(false, "{}", e.to_string());
            return;
        }
    };
}
