//! Common errors when handling cryptographic functions

/// Crypto errors
#[derive(::thiserror::Error, Debug, Copy, Clone)]
pub enum Error {
    /// Error while parsing key material
    #[error("can't parse key")]
    Parsing,
    /// Not enough data
    #[error("not enough data: {0}")]
    NotEnoughData(usize),
    /// buffer too small
    #[error("buffer too small")]
    InsufficientBuffer,
    /// Unsupported Key type found.
    #[error("unsupported key type: {0}")]
    UnsupportedKey(usize),
    /// Unsupported key exchange for this key
    #[error("unsupported key exchange")]
    UnsupportedKeyExchange,
    /// Unsupported cipher
    #[error("unsupported cipher")]
    UnsupportedCipher,
    /// Can not decrypt. Either corrupted or malicious data
    #[error("decrypt: corrupted data")]
    Decrypt,
    /// Can not encrypt. library failure
    #[error("can't encrypt")]
    Encrypt,
}
